@@ -1,5 +1,6 @@
 # coding: utf-8
-from _msgpack import *
+from msgpack.__version__ import *
+from msgpack._msgpack import *
 
 # alias for compatibility to simplejson/marshal/pickle.
 load = unpack
