@@ -6,12 +6,12 @@ from msgpack import Unpacker
 def test_foobar():
     unpacker = Unpacker(read_size=3)
     unpacker.feed('foobar')
-    assert unpacker.unpack() == ord(b'f')
-    assert unpacker.unpack() == ord(b'o')
-    assert unpacker.unpack() == ord(b'o')
-    assert unpacker.unpack() == ord(b'b')
-    assert unpacker.unpack() == ord(b'a')
-    assert unpacker.unpack() == ord(b'r')
+    assert unpacker.unpack() == ord('f')
+    assert unpacker.unpack() == ord('o')
+    assert unpacker.unpack() == ord('o')
+    assert unpacker.unpack() == ord('b')
+    assert unpacker.unpack() == ord('a')
+    assert unpacker.unpack() == ord('r')
     try:
         o = unpacker.unpack()
         print "Oops!", o
@@ -20,14 +20,14 @@ def test_foobar():
         assert 1
     else:
         assert 0
-    unpacker.feed(b'foo')
-    unpacker.feed(b'bar')
+    unpacker.feed('foo')
+    unpacker.feed('bar')
 
     k = 0
-    for o, e in zip(unpacker, b'foobarbaz'):
+    for o, e in zip(unpacker, 'foobarbaz'):
         assert o == ord(e)
         k += 1
-    assert k == len(b'foobar')
+    assert k == len('foobar')
 
 if __name__ == '__main__':
     test_foobar()
